==> nextcloud-21.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/pl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Wersja {version} jest dostępna. Uzyskaj więcej informacji na temat aktualizacji.",
    "Channel updated" : "Zaktualizowano kanał",
    "Web updater is disabled" : "Aktualizator sieciowy jest wyłączony",
    "Update notifications" : "Powiadomienia o aktualizacji",
    "The update server could not be reached since %d days to check for new updates." : "Serwer aktualizacji nie był dostępny od %d dni w celu sprawdzenia dostępności nowych aktualizacji.",
    "Please check the Nextcloud and server log files for errors." : "Sprawdź pliki dziennika Nextcloud i serwera pod kątem błędów.",
    "Update to %1$s is available." : "Dostępna jest aktualizacja do wersji %1$s.",
    "Update for %1$s to version %2$s is available." : "Dostępna jest aktualizacja dla %1$s do wersji %2$s.",
    "Update for {app} to version %s is available." : "Dostępna jest aktualizacja dla {app} do wersji %s.",
    "Update notification" : "Powiadomienie o aktualizacji",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Wyświetla powiadomienia o aktualizacji dla usługi Nextcloud i udostępnia SSO dla aktualizatora.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Wersja, której używasz, nie jest już wspierana. Pamiętaj, aby jak najszybciej zaktualizować do nowszej wersji.",
    "Apps missing compatible version" : "W aplikacjach brakuje zgodnej wersji",
    "View in store" : "Zobacz w sklepie",
    "Apps with compatible version" : "Aplikacje z kompatybilną wersją",
    "Open updater" : "Otwórz aktualizator",
    "Download now" : "Pobierz teraz",
    "Please use the command line updater to update." : "Użyj wiersza poleceń do aktualizacji.",
    "What's new?" : "Co nowego?",
    "The update check is not yet finished. Please refresh the page." : "Sprawdzanie aktualizacji nie zostało jeszcze zakończone. Odśwież stronę.",
    "Your version is up to date." : "Posiadasz aktualną wersję.",
    "A non-default update server is in use to be checked for updates:" : "Do sprawdzania aktualizacji nie są używane domyślne serwery aktualizacji:",
    "Update channel:" : "Kanał aktualizacji:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Zawsze możesz zaktualizować do nowszej wersji. Ale nigdy nie możesz powrócić do wersji bardziej stabilnej.",
    "Notify members of the following groups about available updates:" : "Powiadom członków następujących grup o dostępnych aktualizacjach:",
    "Only notifications for app updates are available." : "Dostępne są tylko powiadomienia o aktualizacjach aplikacji.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Wybrany kanał aktualizacji dla dedykowanych powiadomień dla serwera jest nieaktualny.",
    "The selected update channel does not support updates of the server." : "Wybrany kanał aktualizacji nie obsługuje danego serwera.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Dostępna jest nowa wersja: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Zauważ, że po nowej wersji aktualizacja pojawia się dopiero po pierwszym mniejszym wydaniu lub później. Udostępniamy nowe wersje rozłożone w czasie dla naszych użytkowników i czasami pomijamy wersję w przypadku znalezienia problemów. Dowiedz się więcej o aktualizacjach i kanałach wydań pod adresem {link}",
    "Checked on {lastCheckedDate}" : "Sprawdzono {lastCheckedDate}",
    "Checking apps for compatible versions" : "Sprawdzanie aplikacji pod kątem kompatybilnych wersji",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Upewnij się, że opcja <samp>appstoreenabled</samp> w Twoim config.php nie jest ustawiona na false.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Nie można połączyć się z appstore lub całkowicie zgłasza brak aktualizacji. Wyszukaj aktualizacje ręcznie lub upewnij się, że masz dostęp do Internetu i możesz łączyć się z appstore.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Wszystkie</strong> aplikacje mają dostępną wersję zgodną z tą wersją Nextcloud",
    "View changelog" : "Zobacz listę zmian",
    "Enterprise" : "Komercyjna",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Do użytku firmowego. Zapewnia zawsze najnowszy poziom poprawek, które zostaną wprowadzone dopiero po przetestowaniu przez Nextcloud GmbH. Aktualizacja usunie błędy krytyczne i wprowadzi dodatkowe ulepszenia. Ten kanał jest dostępny tylko dla klientów, którzy posiadają pakiet dla firm.",
    "Stable" : "Stabilna",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Najnowsza wersja stabilna. Jest odpowiednia do regularnego używania i zawsze będzie aktualizowana do najnowszej wersji głównej.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Wersja przedpremierowa tylko do testowania nowych funkcji. Nie jest do środowisk produkcyjnych.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n</strong> aplikacja nie ma kompatybilnej wersji dla tej wersji Nextcloud","<strong>%n</strong> aplikacje nie mają kompatybilnej wersji dla tej wersji Nextcloud","<strong>%n</strong> aplikacji nie ma kompatybilnej wersji dla tej wersji Nextcloud","<strong>%n</strong> aplikacji nie ma kompatybilnej wersji dla tej wersji Nextcloud"],
    "Apps missing updates" : "Brakujące aktualizacje aplikacji",
    "Apps with available updates" : "Dostępne aktualizacje dla aplikacji",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Zauważ, że po opublikowaniu nowej wersji może minąć trochę czasu, zanim pojawi się ona tutaj. Publikację dla naszych użytkowników rozkładamy w czasie, a czasami pomijamy wersję, gdy znajdziemy jakieś błędy.",
    "Only notification for app updates are available." : "Dostępne są tylko powiadomienia o aktualizacjach aplikacji.",
    "Checking apps for compatible updates" : "Sprawdzanie aplikacji pod kątem zgodnych aktualizacji",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Wszystkie</strong> aplikacje mają dostępną aktualizację dla tej wersji",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplikacja nie ma dostępnej aktualizacji dla tej wersji","<strong>%n</strong> aplikacje nie mają dostępnych aktualizacji dla tej wersji","<strong>%n</strong> aplikacji nie ma dostępnych aktualizacji dla tej wersji","<strong>%n</strong> aplikacje nie mają dostępnych aktualizacji dla tej wersji"]
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/pl.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Wersja {version} jest dostępna. Uzyskaj więcej informacji na temat aktualizacji.",
    "Channel updated" : "Zaktualizowano kanał",
    "Web updater is disabled" : "Aktualizator sieciowy jest wyłączony",
    "Update notifications" : "Powiadomienia o aktualizacji",
    "The update server could not be reached since %d days to check for new updates." : "Serwer aktualizacji nie był dostępny od %d dni w celu sprawdzenia dostępności nowych aktualizacji.",
    "Please check the Nextcloud and server log files for errors." : "Sprawdź pliki dziennika Nextcloud i serwera pod kątem błędów.",
    "Update to %1$s is available." : "Dostępna jest aktualizacja do wersji %1$s.",
    "Update to {serverAndVersion} is available." : "Dostępna jest aktualizacja dla {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Dostępna jest aktualizacja dla {app} do wersji %s.",
    "Update notification" : "Powiadomienie o aktualizacji",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Wyświetla powiadomienia o aktualizacji dla usługi Nextcloud i udostępnia SSO dla aktualizatora.",
    "Update" : "Aktualizacja",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Wersja, której używasz, nie jest już wspierana. Pamiętaj, aby jak najszybciej zaktualizować do nowszej wersji.",
    "Apps missing compatible version" : "W aplikacjach brakuje zgodnej wersji",
    "View in store" : "Zobacz w sklepie",
    "Apps with compatible version" : "Aplikacje z kompatybilną wersją",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Należy pamiętać, że aktualizacja sieciowa nie jest zalecana przy więcej niż 100 użytkownikach! Zamiast tego użyj narzędzia do aktualizacji wiersza poleceń!",
    "Open updater" : "Otwórz aktualizator",
    "Download now" : "Pobierz teraz",
    "What's new?" : "Co nowego?",
    "View changelog" : "Zobacz listę zmian",
    "The update check is not yet finished. Please refresh the page." : "Sprawdzanie aktualizacji nie zostało jeszcze zakończone. Odśwież stronę.",
    "Your version is up to date." : "Posiadasz aktualną wersję.",
    "A non-default update server is in use to be checked for updates:" : "Do sprawdzania aktualizacji nie są używane domyślne serwery aktualizacji:",
    "Update channel" : "Zaktualizuj kanał",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Zmiana kanału aktualizacji wpływa również na stronę zarządzania aplikacjami. Np. po przejściu na kanał beta aktualizacje aplikacji w wersji beta będą oferowane na stronie zarządzania aplikacjami.",
    "Current update channel:" : "Aktualny kanał aktualizacji:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Zawsze możesz zaktualizować do nowszej wersji. Ale nigdy nie możesz powrócić do wersji bardziej stabilnej.",
    "Notify members of the following groups about available updates:" : "Powiadom członków następujących grup o dostępnych aktualizacjach:",
    "No groups" : "Brak grup",
    "Only notifications for app updates are available." : "Dostępne są tylko powiadomienia o aktualizacjach aplikacji.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Wybrany kanał aktualizacji dla dedykowanych powiadomień dla serwera jest nieaktualny.",
    "The selected update channel does not support updates of the server." : "Wybrany kanał aktualizacji nie obsługuje danego serwera.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Dostępna jest nowa wersja: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Zauważ, że po nowej wersji aktualizacja pojawia się dopiero po pierwszym mniejszym wydaniu lub później. Udostępniamy nowe wersje rozłożone w czasie dla naszych użytkowników i czasami pomijamy wersję w przypadku znalezienia problemów. Dowiedz się więcej o aktualizacjach i kanałach wydań pod adresem {link}",
    "Checking apps for compatible versions" : "Sprawdzanie aplikacji pod kątem kompatybilnych wersji",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Upewnij się, że opcja <samp>appstoreenabled</samp> w Twoim config.php nie jest ustawiona na false.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Nie można połączyć się ze sklepem z aplikacjami lub zgłasza brak aktualizacji. Wyszukaj aktualizacje ręcznie lub upewnij się, że serwer ma dostęp do Internetu i może łączyć się ze sklepem z aplikacjami.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Wszystkie</strong> aplikacje mają kompatybilną wersję dla tej wersji Nextcloud.",
    "Enterprise" : "Komercyjna",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Do użytku firmowego. Zapewnia zawsze najnowszy poziom poprawek, które zostaną wprowadzone dopiero po przetestowaniu przez Nextcloud GmbH. Aktualizacja usunie błędy krytyczne i wprowadzi dodatkowe ulepszenia. Ten kanał jest dostępny tylko dla klientów, którzy posiadają pakiet dla firm.",
    "Stable" : "Stabilna",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Najnowsza wersja stabilna. Jest odpowiednia do regularnego używania i zawsze będzie aktualizowana do najnowszej wersji głównej.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Wersja przedpremierowa tylko do testowania nowych funkcji. Nie jest do środowisk produkcyjnych.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplikacja nie ma kompatybilnej wersji z tą wersją Nextcloud.","<strong>%n</strong> aplikacje nie ma kompatybilnej wersji z tą wersją Nextcloud.","<strong>%n</strong> aplikacji nie ma kompatybilnej wersji z tą wersją Nextcloud.","<strong>%n</strong> aplikacji nie ma kompatybilnej wersji z tą wersją Nextcloud."],
    "Please use the command line updater to update." : "Użyj wiersza poleceń do aktualizacji.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Możesz zmienić kanał aktualizacji poniżej, co wpływa również na stronę zarządzania aplikacjami. Np. po przejściu na kanał beta aktualizacje aplikacji beta będą dostępne na stronie zarządzania aplikacjami.",
    "Update channel:" : "Kanał aktualizacji:",
    "Checked on {lastCheckedDate}" : "Sprawdzono {lastCheckedDate}"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
